==> 1.0.0.tar.gz: lib/src/utils/model_utils/fw_method_name_util.dart <==
import '../../models/fw_method_name.dart';

const fwMethodNameMap = <String, FWMethodName>{
  "fw:sdk-init": FWMethodName.sdkInit,
  "fw:custom-cta-click": FWMethodName.customCTAClick,
  "fw:video-playback": FWMethodName.videoPlayback,
  "fw:video-feed-click": FWMethodName.videoFeedClick,
};

class FWMethodNameUtil {
  static FWMethodName? createMethodName(String rawName) {
    final eventName = fwMethodNameMap[rawName];
    return eventName;
  }

  static String convertToNativeMethod(FWNativeMethodName methodName) {
    String nativeMethod = "";
    switch (methodName) {
      case FWNativeMethodName.init:
        nativeMethod = "init";
        break;
      case FWNativeMethodName.openVideoPlayer:
        nativeMethod = "openVideoPlayer";
        break;
      case FWNativeMethodName.setCustomCTAClickEnabled:
        nativeMethod = "setCustomCTAClickEnabled";
        break;
      case FWNativeMethodName.setVideoPlaybackEventEnabled:
        nativeMethod = "setVideoPlaybackEventEnabled";
        break;
      case FWNativeMethodName.setShareBaseURL:
        nativeMethod = "setShareBaseURL";
        break;
      case FWNativeMethodName.setAdBadgeConfiguration:
        nativeMethod = "setAdBadgeConfiguration";
        break;
    }

    return nativeMethod;
  }
}

const fwShoppingMethodNameMap = <String, FWShoppingMethodName>{
  "fw:shopping:add-to-cart": FWShoppingMethodName.addToCart,
  "fw:shopping:update-product-details":
      FWShoppingMethodName.updateProductDetails,
  "fw:shopping:will-display-product": FWShoppingMethodName.willDisplayProduct,
};

class FWShoppingMethodNameUtil {
  static FWShoppingMethodName? createMethodName(String rawName) {
    final methodName = fwShoppingMethodNameMap[rawName];
    return methodName;
  }

  static String convertToNativeMethod(FWShoppingNativeMethodName methodName) {
    String nativeMethod = "";
    switch (methodName) {
      case FWShoppingNativeMethodName.init:
        nativeMethod = "init";
        break;
      case FWShoppingNativeMethodName.setCartIconVisible:
        nativeMethod = "setCartIconVisible";
        break;
      case FWShoppingNativeMethodName.setCartItemCount:
        nativeMethod = "setCartItemCount";
        break;
      case FWShoppingNativeMethodName.exitCartPage:
        nativeMethod = "exitCartPage";
        break;
    }

    return nativeMethod;
  }
}

const fwVideoFeedMethodNameMap = <String, FWVideoFeedMethodName>{
  "onVideoFeedLoadFinished": FWVideoFeedMethodName.onVideoFeedLoadFinished,
};

class FWVideoFeedMethodNameUtil {
  static FWVideoFeedMethodName? createMethodName(String rawName) {
    final methodName = fwVideoFeedMethodNameMap[rawName];
    return methodName;
  }

  static String convertToNativeMethod(FWVideoFeedNativeMethodName methodName) {
    String nativeMethod = "";

    switch (methodName) {
      case FWVideoFeedNativeMethodName.setVideoFeedConfiguration:
        nativeMethod = "setVideoFeedConfiguration";
        break;
      case FWVideoFeedNativeMethodName.setVideoPlayerConfiguration:
        nativeMethod = "setVideoPlayerConfiguration";

        break;
      case FWVideoFeedNativeMethodName.refresh:
        nativeMethod = "refresh";
        break;
    }

    return nativeMethod;
  }
}

const fwLiveStreamMethodNameMap = <String, FWLiveStreamMethodName>{
  "fw:livestream": FWLiveStreamMethodName.onLiveStreamEvent,
  "fw:livestream-chat": FWLiveStreamMethodName.onLiveStreamChatEvent,
};

class FWLiveStreamMethodNameUtil {
  static FWLiveStreamMethodName? createMethodName(String rawName) {
    final methodName = fwLiveStreamMethodNameMap[rawName];
    return methodName;
  }

  static String convertToNativeMethod(FWLiveStreamNativeMethodName methodName) {
    String nativeMethod = "";

    switch (methodName) {
      case FWLiveStreamNativeMethodName.init:
        nativeMethod = "init";
        break;
    }

    return nativeMethod;
  }
}

==> 1.3.0.tar.gz: lib/src/utils/model_utils/fw_method_name_util.dart <==
import '../../models/fw_method_name.dart';

const fwMethodNameMap = <String, FWMethodName>{
  "fw:sdk-init": FWMethodName.sdkInit,
  "fw:custom-cta-click": FWMethodName.customCTAClick,
  "fw:video-playback": FWMethodName.videoPlayback,
  "fw:video-feed-click": FWMethodName.videoFeedClick,
};

class FWMethodNameUtil {
  static FWMethodName? createMethodName(String rawName) {
    final eventName = fwMethodNameMap[rawName];
    return eventName;
  }

  static String convertToNativeMethod(FWNativeMethodName methodName) {
    String nativeMethod = "";
    switch (methodName) {
      case FWNativeMethodName.init:
        nativeMethod = "init";
        break;
      case FWNativeMethodName.openVideoPlayer:
        nativeMethod = "openVideoPlayer";
        break;
      case FWNativeMethodName.setCustomCTAClickEnabled:
        nativeMethod = "setCustomCTAClickEnabled";
        break;
      case FWNativeMethodName.setVideoPlaybackEventEnabled:
        nativeMethod = "setVideoPlaybackEventEnabled";
        break;
      case FWNativeMethodName.setShareBaseURL:
        nativeMethod = "setShareBaseURL";
        break;
      case FWNativeMethodName.setAdBadgeConfiguration:
        nativeMethod = "setAdBadgeConfiguration";
        break;
    }

    return nativeMethod;
  }
}

const fwShoppingMethodNameMap = <String, FWShoppingMethodName>{
  "fw:shopping:add-to-cart": FWShoppingMethodName.addToCart,
  "fw:shopping:update-product-details":
      FWShoppingMethodName.updateProductDetails,
  "fw:shopping:will-display-product": FWShoppingMethodName.willDisplayProduct,
  "fw:shopping:click-cart-icon": FWShoppingMethodName.clickCartIcon,
};

class FWShoppingMethodNameUtil {
  static FWShoppingMethodName? createMethodName(String rawName) {
    final methodName = fwShoppingMethodNameMap[rawName];
    return methodName;
  }

  static String convertToNativeMethod(FWShoppingNativeMethodName methodName) {
    String nativeMethod = "";
    switch (methodName) {
      case FWShoppingNativeMethodName.init:
        nativeMethod = "init";
        break;
      case FWShoppingNativeMethodName.setCartIconVisible:
        nativeMethod = "setCartIconVisible";
        break;
      case FWShoppingNativeMethodName.setCartItemCount:
        nativeMethod = "setCartItemCount";
        break;
      case FWShoppingNativeMethodName.setCustomClickCartIconEnabled:
        nativeMethod = "setCustomClickCartIconEnabled";
        break;
    }

    return nativeMethod;
  }
}

const fwVideoFeedMethodNameMap = <String, FWVideoFeedMethodName>{
  "onVideoFeedLoadFinished": FWVideoFeedMethodName.onVideoFeedLoadFinished,
};

class FWVideoFeedMethodNameUtil {
  static FWVideoFeedMethodName? createMethodName(String rawName) {
    final methodName = fwVideoFeedMethodNameMap[rawName];
    return methodName;
  }

  static String convertToNativeMethod(FWVideoFeedNativeMethodName methodName) {
    String nativeMethod = "";

    switch (methodName) {
      case FWVideoFeedNativeMethodName.setVideoFeedConfiguration:
        nativeMethod = "setVideoFeedConfiguration";
        break;
      case FWVideoFeedNativeMethodName.setVideoPlayerConfiguration:
        nativeMethod = "setVideoPlayerConfiguration";

        break;
      case FWVideoFeedNativeMethodName.refresh:
        nativeMethod = "refresh";
        break;
    }

    return nativeMethod;
  }
}

const fwLiveStreamMethodNameMap = <String, FWLiveStreamMethodName>{
  "fw:livestream": FWLiveStreamMethodName.onLiveStreamEvent,
  "fw:livestream-chat": FWLiveStreamMethodName.onLiveStreamChatEvent,
};

class FWLiveStreamMethodNameUtil {
  static FWLiveStreamMethodName? createMethodName(String rawName) {
    final methodName = fwLiveStreamMethodNameMap[rawName];
    return methodName;
  }

  static String convertToNativeMethod(FWLiveStreamNativeMethodName methodName) {
    String nativeMethod = "";

    switch (methodName) {
      case FWLiveStreamNativeMethodName.init:
        nativeMethod = "init";
        break;
    }

    return nativeMethod;
  }
}

class FWNavigatorMethodNameUtil {
  static String convertToNativeMethod(FWNavigatorNativeMethodName methodName) {
    String nativeMethod = "";

    switch (methodName) {
      case FWNavigatorNativeMethodName.pushNativeContainer:
        nativeMethod = "pushNativeContainer";
        break;
      case FWNavigatorNativeMethodName.popNativeContainer:
        nativeMethod = "popNativeContainer";
        break;
      case FWNavigatorNativeMethodName.canPopNativeContainer:
        nativeMethod = "canPopNativeContainer";
        break;
    }

    return nativeMethod;
  }
}

const fwStoryBlockMethodNameMap = <String, FWStoryBlockMethodName>{
  "onStoryBlockLoadFinished": FWStoryBlockMethodName.onStoryBlockLoadFinished,
};

class FWStoryBlockMethodNameUtil {
  static FWStoryBlockMethodName? createMethodName(String rawName) {
    final methodName = fwStoryBlockMethodNameMap[rawName];
    return methodName;
  }

  static String convertToNativeMethod(FWStoryBlockNativeMethodName methodName) {
    String nativeMethod = "";

    switch (methodName) {
      case FWStoryBlockNativeMethodName.showAndroidNativeFragment:
        nativeMethod = "showAndroidNativeFragment";
        break;
    }

    return nativeMethod;
  }
}
